/// <reference path="meteor-persistent-session.d.ts" />

Session.setTemp('a', 'a');
Session.setPersistent('a', 'a');
Session.setAuth('a', 'a');

Session.setDefaultTemp('a', 'a');
Session.setDefaultPersistent('a', 'a');
Session.setDefaultAuth('a', 'a');

Session.makeTemp('a');
Session.makePersistent('a');
Session.makeAuth('a');

Session.clear();
Session.clear('a');
Session.clearTemp();
Session.clearPersistent();
Session.clearAuth();
